from __future__ import annotations

from enum import Enum
from typing import Any, Dict, List, Type

import System
import System.Collections
import System.Configuration
import System.Configuration.Assemblies
import System.Data
import System.Globalization
import System.IO
import System.Reflection
import System.Runtime
import System.Runtime.CompilerServices
import System.Runtime.InteropServices
import System.Runtime.Remoting
import System.Runtime.Serialization
import System.Security
import System.Security.AccessControl
import System.Security.Cryptography
import System.Security.Cryptography.X509Certificates
import System.Security.Policy
import System.Threading
import System.Threading.Tasks
import System.Xml
import System.Xml.Serialization
from System.ComponentModel import MarshalByValueComponent


class XmlSchema:

    @property
    def AttributeFormDefault(self): ...

    @AttributeFormDefault.setter
    def AttributeFormDefault(self): ...

    @property
    def AttributeGroups(self): ...

    @AttributeGroups.setter
    def AttributeGroups(self): ...

    @property
    def Attributes(self): ...

    @Attributes.setter
    def Attributes(self): ...

    @property
    def BlockDefault(self): ...

    @BlockDefault.setter
    def BlockDefault(self): ...

    def Compile(self,
            _: ValidationEventHandler,
            __: System.Xml.XmlResolver,
            ) -> None: ...

    @property
    def ElementFormDefault(self): ...

    @ElementFormDefault.setter
    def ElementFormDefault(self): ...

    @property
    def Elements(self): ...

    @Elements.setter
    def Elements(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def FinalDefault(self): ...

    @FinalDefault.setter
    def FinalDefault(self): ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Groups(self): ...

    @Groups.setter
    def Groups(self): ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    @property
    def Includes(self): ...

    @Includes.setter
    def Includes(self): ...

    def InstanceNamespace(self, *args, **kwargs) -> Any: ...

    @property
    def IsCompiled(self): ...

    @IsCompiled.setter
    def IsCompiled(self): ...

    @property
    def Items(self): ...

    @Items.setter
    def Items(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    def Namespace(self, *args, **kwargs) -> Any: ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    @property
    def Notations(self): ...

    @Notations.setter
    def Notations(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    def Read(self,
            _: System.IO.TextReader,
            __: ValidationEventHandler,
            ) -> XmlSchema: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SchemaTypes(self): ...

    @SchemaTypes.setter
    def SchemaTypes(self): ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    @property
    def TargetNamespace(self): ...

    @TargetNamespace.setter
    def TargetNamespace(self): ...

    def ToString(self) -> str: ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    @property
    def Version(self): ...

    @Version.setter
    def Version(self): ...

    def Write(self,
            _: System.IO.TextWriter,
            __: System.Xml.XmlNamespaceManager,
            ) -> None: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_AttributeFormDefault(self) -> XmlSchemaForm: ...

    def get_AttributeGroups(self) -> XmlSchemaObjectTable: ...

    def get_Attributes(self) -> XmlSchemaObjectTable: ...

    def get_BlockDefault(self) -> XmlSchemaDerivationMethod: ...

    def get_ElementFormDefault(self) -> XmlSchemaForm: ...

    def get_Elements(self) -> XmlSchemaObjectTable: ...

    def get_FinalDefault(self) -> XmlSchemaDerivationMethod: ...

    def get_Groups(self) -> XmlSchemaObjectTable: ...

    def get_Id(self) -> str: ...

    def get_Includes(self) -> XmlSchemaObjectCollection: ...

    def get_IsCompiled(self) -> bool: ...

    def get_Items(self) -> XmlSchemaObjectCollection: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Notations(self) -> XmlSchemaObjectTable: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_SchemaTypes(self) -> XmlSchemaObjectTable: ...

    def get_SourceUri(self) -> str: ...

    def get_TargetNamespace(self) -> str: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def get_Version(self) -> str: ...

    def set_AttributeFormDefault(self, _: XmlSchemaForm) -> None: ...

    def set_BlockDefault(self, _: XmlSchemaDerivationMethod) -> None: ...

    def set_ElementFormDefault(self, _: XmlSchemaForm) -> None: ...

    def set_FinalDefault(self, _: XmlSchemaDerivationMethod) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_TargetNamespace(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...

    def set_Version(self, _: str) -> None: ...


class XmlTypeCode:

    def AnyAtomicType(self, *args, **kwargs) -> Any: ...

    def AnyUri(self, *args, **kwargs) -> Any: ...

    def Attribute(self, *args, **kwargs) -> Any: ...

    def Base64Binary(self, *args, **kwargs) -> Any: ...

    def Boolean(self, *args, **kwargs) -> Any: ...

    def Byte(self, *args, **kwargs) -> Any: ...

    def Comment(self, *args, **kwargs) -> Any: ...

    def CompareTo(self, _: object) -> int: ...

    def Date(self, *args, **kwargs) -> Any: ...

    def DateTime(self, *args, **kwargs) -> Any: ...

    def DayTimeDuration(self, *args, **kwargs) -> Any: ...

    def Decimal(self, *args, **kwargs) -> Any: ...

    def Document(self, *args, **kwargs) -> Any: ...

    def Double(self, *args, **kwargs) -> Any: ...

    def Duration(self, *args, **kwargs) -> Any: ...

    def Element(self, *args, **kwargs) -> Any: ...

    def Entity(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Float(self, *args, **kwargs) -> Any: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GDay(self, *args, **kwargs) -> Any: ...

    def GMonth(self, *args, **kwargs) -> Any: ...

    def GMonthDay(self, *args, **kwargs) -> Any: ...

    def GYear(self, *args, **kwargs) -> Any: ...

    def GYearMonth(self, *args, **kwargs) -> Any: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def HexBinary(self, *args, **kwargs) -> Any: ...

    def Id(self, *args, **kwargs) -> Any: ...

    def Idref(self, *args, **kwargs) -> Any: ...

    def Int(self, *args, **kwargs) -> Any: ...

    def Integer(self, *args, **kwargs) -> Any: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def Item(self, *args, **kwargs) -> Any: ...

    def Language(self, *args, **kwargs) -> Any: ...

    def Long(self, *args, **kwargs) -> Any: ...

    def MemberwiseClone(self) -> object: ...

    def NCName(self, *args, **kwargs) -> Any: ...

    def Name(self, *args, **kwargs) -> Any: ...

    def Namespace(self, *args, **kwargs) -> Any: ...

    def NegativeInteger(self, *args, **kwargs) -> Any: ...

    def NmToken(self, *args, **kwargs) -> Any: ...

    def Node(self, *args, **kwargs) -> Any: ...

    def NonNegativeInteger(self, *args, **kwargs) -> Any: ...

    def NonPositiveInteger(self, *args, **kwargs) -> Any: ...

    def NormalizedString(self, *args, **kwargs) -> Any: ...

    def Notation(self, *args, **kwargs) -> Any: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def PositiveInteger(self, *args, **kwargs) -> Any: ...

    def ProcessingInstruction(self, *args, **kwargs) -> Any: ...

    def QName(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Short(self, *args, **kwargs) -> Any: ...

    def String(self, *args, **kwargs) -> Any: ...

    def Text(self, *args, **kwargs) -> Any: ...

    def Time(self, *args, **kwargs) -> Any: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def Token(self, *args, **kwargs) -> Any: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def UnsignedByte(self, *args, **kwargs) -> Any: ...

    def UnsignedInt(self, *args, **kwargs) -> Any: ...

    def UnsignedLong(self, *args, **kwargs) -> Any: ...

    def UnsignedShort(self, *args, **kwargs) -> Any: ...

    def UntypedAtomic(self, *args, **kwargs) -> Any: ...

    def YearMonthDuration(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class XmlSchemaSimpleType:

    @property
    def Annotation(self): ...

    @Annotation.setter
    def Annotation(self): ...

    @property
    def BaseSchemaType(self): ...

    @BaseSchemaType.setter
    def BaseSchemaType(self): ...

    @property
    def BaseXmlSchemaType(self): ...

    @BaseXmlSchemaType.setter
    def BaseXmlSchemaType(self): ...

    @property
    def Content(self): ...

    @Content.setter
    def Content(self): ...

    @property
    def Datatype(self): ...

    @Datatype.setter
    def Datatype(self): ...

    @property
    def DerivedBy(self): ...

    @DerivedBy.setter
    def DerivedBy(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def Final(self): ...

    @Final.setter
    def Final(self): ...

    @property
    def FinalResolved(self): ...

    @FinalResolved.setter
    def FinalResolved(self): ...

    def Finalize(self) -> None: ...

    def GetBuiltInComplexType(self,
            _: XmlTypeCode,
            ) -> XmlSchemaComplexType: ...

    def GetBuiltInSimpleType(self,
            _: XmlTypeCode,
            ) -> XmlSchemaSimpleType: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    def IsDerivedFrom(self,
            _: XmlSchemaType,
            __: XmlSchemaType,
            ___: XmlSchemaDerivationMethod,
            ) -> bool: ...

    @property
    def IsMixed(self): ...

    @IsMixed.setter
    def IsMixed(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Name(self): ...

    @Name.setter
    def Name(self): ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    @property
    def QualifiedName(self): ...

    @QualifiedName.setter
    def QualifiedName(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    @property
    def TypeCode(self): ...

    @TypeCode.setter
    def TypeCode(self): ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Annotation(self) -> XmlSchemaAnnotation: ...

    def get_BaseSchemaType(self) -> object: ...

    def get_BaseXmlSchemaType(self) -> XmlSchemaType: ...

    def get_Content(self) -> XmlSchemaSimpleTypeContent: ...

    def get_Datatype(self) -> XmlSchemaDatatype: ...

    def get_DerivedBy(self) -> XmlSchemaDerivationMethod: ...

    def get_Final(self) -> XmlSchemaDerivationMethod: ...

    def get_FinalResolved(self) -> XmlSchemaDerivationMethod: ...

    def get_Id(self) -> str: ...

    def get_IsMixed(self) -> bool: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Name(self) -> str: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_QualifiedName(self) -> System.Xml.XmlQualifiedName: ...

    def get_SourceUri(self) -> str: ...

    def get_TypeCode(self) -> XmlTypeCode: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def set_Annotation(self, _: XmlSchemaAnnotation) -> None: ...

    def set_Content(self, _: XmlSchemaSimpleTypeContent) -> None: ...

    def set_Final(self, _: XmlSchemaDerivationMethod) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_IsMixed(self, _: bool) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Name(self, _: str) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...


class XmlSchemaSet:

    def Add(self, _: str, __: str) -> XmlSchema: ...

    @property
    def CompilationSettings(self): ...

    @CompilationSettings.setter
    def CompilationSettings(self): ...

    def Compile(self) -> None: ...

    def Contains(self, _: str) -> bool: ...

    def CopyTo(self, _: List[XmlSchema], __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def GlobalAttributes(self): ...

    @GlobalAttributes.setter
    def GlobalAttributes(self): ...

    @property
    def GlobalElements(self): ...

    @GlobalElements.setter
    def GlobalElements(self): ...

    @property
    def GlobalTypes(self): ...

    @GlobalTypes.setter
    def GlobalTypes(self): ...

    @property
    def IsCompiled(self): ...

    @IsCompiled.setter
    def IsCompiled(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def NameTable(self): ...

    @NameTable.setter
    def NameTable(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: XmlSchema) -> XmlSchema: ...

    def RemoveRecursive(self, _: XmlSchema) -> bool: ...

    def Reprocess(self, _: XmlSchema) -> XmlSchema: ...

    def Schemas(self, _: str) -> System.Collections.ICollection: ...

    def ToString(self) -> str: ...

    def ValidationEventHandler(self, *args, **kwargs) -> Any: ...

    @property
    def XmlResolver(self): ...

    @XmlResolver.setter
    def XmlResolver(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def add_ValidationEventHandler(self,
            _: ValidationEventHandler,
            ) -> None: ...

    def get_CompilationSettings(self) -> XmlSchemaCompilationSettings: ...

    def get_Count(self) -> int: ...

    def get_GlobalAttributes(self) -> XmlSchemaObjectTable: ...

    def get_GlobalElements(self) -> XmlSchemaObjectTable: ...

    def get_GlobalTypes(self) -> XmlSchemaObjectTable: ...

    def get_IsCompiled(self) -> bool: ...

    def get_NameTable(self) -> System.Xml.XmlNameTable: ...

    def remove_ValidationEventHandler(self,
            _: ValidationEventHandler,
            ) -> None: ...

    def set_CompilationSettings(self,
            _: XmlSchemaCompilationSettings,
            ) -> None: ...

    def set_XmlResolver(self, _: System.Xml.XmlResolver) -> None: ...


class XmlSchemaForm:

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def Qualified(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def Unqualified(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class XmlSchemaType:

    @property
    def Annotation(self): ...

    @Annotation.setter
    def Annotation(self): ...

    @property
    def BaseSchemaType(self): ...

    @BaseSchemaType.setter
    def BaseSchemaType(self): ...

    @property
    def BaseXmlSchemaType(self): ...

    @BaseXmlSchemaType.setter
    def BaseXmlSchemaType(self): ...

    @property
    def Datatype(self): ...

    @Datatype.setter
    def Datatype(self): ...

    @property
    def DerivedBy(self): ...

    @DerivedBy.setter
    def DerivedBy(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def Final(self): ...

    @Final.setter
    def Final(self): ...

    @property
    def FinalResolved(self): ...

    @FinalResolved.setter
    def FinalResolved(self): ...

    def Finalize(self) -> None: ...

    def GetBuiltInComplexType(self,
            _: XmlTypeCode,
            ) -> XmlSchemaComplexType: ...

    def GetBuiltInSimpleType(self,
            _: XmlTypeCode,
            ) -> XmlSchemaSimpleType: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    def IsDerivedFrom(self,
            _: XmlSchemaType,
            __: XmlSchemaType,
            ___: XmlSchemaDerivationMethod,
            ) -> bool: ...

    @property
    def IsMixed(self): ...

    @IsMixed.setter
    def IsMixed(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Name(self): ...

    @Name.setter
    def Name(self): ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    @property
    def QualifiedName(self): ...

    @QualifiedName.setter
    def QualifiedName(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    @property
    def TypeCode(self): ...

    @TypeCode.setter
    def TypeCode(self): ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Annotation(self) -> XmlSchemaAnnotation: ...

    def get_BaseSchemaType(self) -> object: ...

    def get_BaseXmlSchemaType(self) -> XmlSchemaType: ...

    def get_Datatype(self) -> XmlSchemaDatatype: ...

    def get_DerivedBy(self) -> XmlSchemaDerivationMethod: ...

    def get_Final(self) -> XmlSchemaDerivationMethod: ...

    def get_FinalResolved(self) -> XmlSchemaDerivationMethod: ...

    def get_Id(self) -> str: ...

    def get_IsMixed(self) -> bool: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Name(self) -> str: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_QualifiedName(self) -> System.Xml.XmlQualifiedName: ...

    def get_SourceUri(self) -> str: ...

    def get_TypeCode(self) -> XmlTypeCode: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def set_Annotation(self, _: XmlSchemaAnnotation) -> None: ...

    def set_Final(self, _: XmlSchemaDerivationMethod) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_IsMixed(self, _: bool) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Name(self, _: str) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...


class XmlSchemaObject:

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_SourceUri(self) -> str: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...


class XmlSchemaContentModel:

    @property
    def Annotation(self): ...

    @Annotation.setter
    def Annotation(self): ...

    @property
    def Content(self): ...

    @Content.setter
    def Content(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Annotation(self) -> XmlSchemaAnnotation: ...

    def get_Content(self) -> XmlSchemaContent: ...

    def get_Id(self) -> str: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_SourceUri(self) -> str: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def set_Annotation(self, _: XmlSchemaAnnotation) -> None: ...

    def set_Content(self, _: XmlSchemaContent) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...


class XmlSchemaDatatype:

    def ChangeType(self,
            _: object,
            __: Type,
            ___: System.Xml.IXmlNamespaceResolver,
            ) -> object: ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def IsDerivedFrom(self, _: XmlSchemaDatatype) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ParseValue(self,
            _: str,
            __: System.Xml.XmlNameTable,
            ___: System.Xml.IXmlNamespaceResolver,
            ) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToString(self) -> str: ...

    @property
    def TokenizedType(self): ...

    @TokenizedType.setter
    def TokenizedType(self): ...

    @property
    def TypeCode(self): ...

    @TypeCode.setter
    def TypeCode(self): ...

    @property
    def ValueType(self): ...

    @ValueType.setter
    def ValueType(self): ...

    @property
    def Variety(self): ...

    @Variety.setter
    def Variety(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_TokenizedType(self) -> System.Xml.XmlTokenizedType: ...

    def get_TypeCode(self) -> XmlTypeCode: ...

    def get_ValueType(self) -> Type: ...

    def get_Variety(self) -> XmlSchemaDatatypeVariety: ...


class XmlSchemaObjectTable:

    def Contains(self, _: System.Xml.XmlQualifiedName) -> bool: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetEnumerator(self) -> System.Collections.IDictionaryEnumerator: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Names(self): ...

    @Names.setter
    def Names(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToString(self) -> str: ...

    @property
    def Values(self): ...

    @Values.setter
    def Values(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Count(self) -> int: ...

    def get_Item(self,
            _: System.Xml.XmlQualifiedName,
            ) -> XmlSchemaObject: ...

    def get_Names(self) -> System.Collections.ICollection: ...

    def get_Values(self) -> System.Collections.ICollection: ...


class XmlSchemaAnyAttribute:

    @property
    def Annotation(self): ...

    @Annotation.setter
    def Annotation(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Namespace(self): ...

    @Namespace.setter
    def Namespace(self): ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    @property
    def ProcessContents(self): ...

    @ProcessContents.setter
    def ProcessContents(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Annotation(self) -> XmlSchemaAnnotation: ...

    def get_Id(self) -> str: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Namespace(self) -> str: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_ProcessContents(self) -> XmlSchemaContentProcessing: ...

    def get_SourceUri(self) -> str: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def set_Annotation(self, _: XmlSchemaAnnotation) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Namespace(self, _: str) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_ProcessContents(self,
            _: XmlSchemaContentProcessing,
            ) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...


class XmlSchemaComplexType:

    @property
    def Annotation(self): ...

    @Annotation.setter
    def Annotation(self): ...

    @property
    def AnyAttribute(self): ...

    @AnyAttribute.setter
    def AnyAttribute(self): ...

    @property
    def AttributeUses(self): ...

    @AttributeUses.setter
    def AttributeUses(self): ...

    @property
    def AttributeWildcard(self): ...

    @AttributeWildcard.setter
    def AttributeWildcard(self): ...

    @property
    def Attributes(self): ...

    @Attributes.setter
    def Attributes(self): ...

    @property
    def BaseSchemaType(self): ...

    @BaseSchemaType.setter
    def BaseSchemaType(self): ...

    @property
    def BaseXmlSchemaType(self): ...

    @BaseXmlSchemaType.setter
    def BaseXmlSchemaType(self): ...

    @property
    def Block(self): ...

    @Block.setter
    def Block(self): ...

    @property
    def BlockResolved(self): ...

    @BlockResolved.setter
    def BlockResolved(self): ...

    @property
    def ContentModel(self): ...

    @ContentModel.setter
    def ContentModel(self): ...

    @property
    def ContentType(self): ...

    @ContentType.setter
    def ContentType(self): ...

    @property
    def ContentTypeParticle(self): ...

    @ContentTypeParticle.setter
    def ContentTypeParticle(self): ...

    @property
    def Datatype(self): ...

    @Datatype.setter
    def Datatype(self): ...

    @property
    def DerivedBy(self): ...

    @DerivedBy.setter
    def DerivedBy(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def Final(self): ...

    @Final.setter
    def Final(self): ...

    @property
    def FinalResolved(self): ...

    @FinalResolved.setter
    def FinalResolved(self): ...

    def Finalize(self) -> None: ...

    def GetBuiltInComplexType(self,
            _: XmlTypeCode,
            ) -> XmlSchemaComplexType: ...

    def GetBuiltInSimpleType(self,
            _: XmlTypeCode,
            ) -> XmlSchemaSimpleType: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    @property
    def IsAbstract(self): ...

    @IsAbstract.setter
    def IsAbstract(self): ...

    def IsDerivedFrom(self,
            _: XmlSchemaType,
            __: XmlSchemaType,
            ___: XmlSchemaDerivationMethod,
            ) -> bool: ...

    @property
    def IsMixed(self): ...

    @IsMixed.setter
    def IsMixed(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Name(self): ...

    @Name.setter
    def Name(self): ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    @property
    def Particle(self): ...

    @Particle.setter
    def Particle(self): ...

    @property
    def QualifiedName(self): ...

    @QualifiedName.setter
    def QualifiedName(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    @property
    def TypeCode(self): ...

    @TypeCode.setter
    def TypeCode(self): ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Annotation(self) -> XmlSchemaAnnotation: ...

    def get_AnyAttribute(self) -> XmlSchemaAnyAttribute: ...

    def get_AttributeUses(self) -> XmlSchemaObjectTable: ...

    def get_AttributeWildcard(self) -> XmlSchemaAnyAttribute: ...

    def get_Attributes(self) -> XmlSchemaObjectCollection: ...

    def get_BaseSchemaType(self) -> object: ...

    def get_BaseXmlSchemaType(self) -> XmlSchemaType: ...

    def get_Block(self) -> XmlSchemaDerivationMethod: ...

    def get_BlockResolved(self) -> XmlSchemaDerivationMethod: ...

    def get_ContentModel(self) -> XmlSchemaContentModel: ...

    def get_ContentType(self) -> XmlSchemaContentType: ...

    def get_ContentTypeParticle(self) -> XmlSchemaParticle: ...

    def get_Datatype(self) -> XmlSchemaDatatype: ...

    def get_DerivedBy(self) -> XmlSchemaDerivationMethod: ...

    def get_Final(self) -> XmlSchemaDerivationMethod: ...

    def get_FinalResolved(self) -> XmlSchemaDerivationMethod: ...

    def get_Id(self) -> str: ...

    def get_IsAbstract(self) -> bool: ...

    def get_IsMixed(self) -> bool: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Name(self) -> str: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_Particle(self) -> XmlSchemaParticle: ...

    def get_QualifiedName(self) -> System.Xml.XmlQualifiedName: ...

    def get_SourceUri(self) -> str: ...

    def get_TypeCode(self) -> XmlTypeCode: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def set_Annotation(self, _: XmlSchemaAnnotation) -> None: ...

    def set_AnyAttribute(self, _: XmlSchemaAnyAttribute) -> None: ...

    def set_Block(self, _: XmlSchemaDerivationMethod) -> None: ...

    def set_ContentModel(self, _: XmlSchemaContentModel) -> None: ...

    def set_Final(self, _: XmlSchemaDerivationMethod) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_IsAbstract(self, _: bool) -> None: ...

    def set_IsMixed(self, _: bool) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Name(self, _: str) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_Particle(self, _: XmlSchemaParticle) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...


class XmlSchemaParticle:

    @property
    def Annotation(self): ...

    @Annotation.setter
    def Annotation(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    @property
    def MaxOccurs(self): ...

    @MaxOccurs.setter
    def MaxOccurs(self): ...

    @property
    def MaxOccursString(self): ...

    @MaxOccursString.setter
    def MaxOccursString(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def MinOccurs(self): ...

    @MinOccurs.setter
    def MinOccurs(self): ...

    @property
    def MinOccursString(self): ...

    @MinOccursString.setter
    def MinOccursString(self): ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Annotation(self) -> XmlSchemaAnnotation: ...

    def get_Id(self) -> str: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_MaxOccurs(self) -> float: ...

    def get_MaxOccursString(self) -> str: ...

    def get_MinOccurs(self) -> float: ...

    def get_MinOccursString(self) -> str: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_SourceUri(self) -> str: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def set_Annotation(self, _: XmlSchemaAnnotation) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_MaxOccurs(self, _: float) -> None: ...

    def set_MaxOccursString(self, _: str) -> None: ...

    def set_MinOccurs(self, _: float) -> None: ...

    def set_MinOccursString(self, _: str) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...


class XmlSchemaCompilationSettings:

    @property
    def EnableUpaCheck(self): ...

    @EnableUpaCheck.setter
    def EnableUpaCheck(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_EnableUpaCheck(self) -> bool: ...

    def set_EnableUpaCheck(self, _: bool) -> None: ...


class XmlSchemaObjectCollection:

    def Add(self, _: XmlSchemaObject) -> int: ...

    @property
    def Capacity(self): ...

    @Capacity.setter
    def Capacity(self): ...

    def Clear(self) -> None: ...

    def Contains(self, _: XmlSchemaObject) -> bool: ...

    def CopyTo(self, _: List[XmlSchemaObject], __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetEnumerator(self) -> System.Collections.IEnumerator: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def IndexOf(self, _: XmlSchemaObject) -> int: ...

    @property
    def InnerList(self): ...

    @InnerList.setter
    def InnerList(self): ...

    def Insert(self, _: int, __: XmlSchemaObject) -> None: ...

    @property
    def List(self): ...

    @List.setter
    def List(self): ...

    def MemberwiseClone(self) -> object: ...

    def OnClear(self) -> None: ...

    def OnClearComplete(self) -> None: ...

    def OnInsert(self, _: int, __: object) -> None: ...

    def OnInsertComplete(self, _: int, __: object) -> None: ...

    def OnRemove(self, _: int, __: object) -> None: ...

    def OnRemoveComplete(self, _: int, __: object) -> None: ...

    def OnSet(self, _: int, __: object, ___: object) -> None: ...

    def OnSetComplete(self, _: int, __: object, ___: object) -> None: ...

    def OnValidate(self, _: object) -> None: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: XmlSchemaObject) -> None: ...

    def RemoveAt(self, _: int) -> None: ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Capacity(self) -> int: ...

    def get_Count(self) -> int: ...

    def get_InnerList(self) -> List: ...

    def get_Item(self, _: int) -> XmlSchemaObject: ...

    def get_List(self) -> List: ...

    def set_Capacity(self, _: int) -> None: ...

    def set_Item(self, _: int, __: XmlSchemaObject) -> None: ...


class XmlSchemaDerivationMethod:

    def All(self, *args, **kwargs) -> Any: ...

    def CompareTo(self, _: object) -> int: ...

    def Empty(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object) -> bool: ...

    def Extension(self, *args, **kwargs) -> Any: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def List(self, *args, **kwargs) -> Any: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Restriction(self, *args, **kwargs) -> Any: ...

    def Substitution(self, *args, **kwargs) -> Any: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def Union(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class ValidationEventHandler:

    def BeginInvoke(self,
            _: object,
            __: ValidationEventArgs,
            ___: Any,
            ____: object,
            ) -> Any: ...

    def Clone(self) -> object: ...

    def Combine(self, _: Any, __: Any) -> Any: ...

    def CombineImpl(self, _: Any) -> Any: ...

    def CreateDelegate(self,
            _: Type,
            __: object,
            ___: str,
            ____: bool,
            _____: bool,
            ) -> Any: ...

    def DynamicInvoke(self, _: List[object]) -> object: ...

    def DynamicInvokeImpl(self, _: List[object]) -> object: ...

    def EndInvoke(self, _: Any) -> None: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetInvocationList(self) -> List[Any]: ...

    def GetMethodImpl(self) -> System.Reflection.MethodInfo: ...

    def GetObjectData(self,
            _: System.Runtime.Serialization.SerializationInfo,
            __: System.Runtime.Serialization.StreamingContext,
            ) -> None: ...

    def GetType(self) -> Type: ...

    def Invoke(self, _: object, __: ValidationEventArgs) -> None: ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Method(self): ...

    @Method.setter
    def Method(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: Any, __: Any) -> Any: ...

    def RemoveAll(self, _: Any, __: Any) -> Any: ...

    def RemoveImpl(self, _: Any) -> Any: ...

    @property
    def Target(self): ...

    @Target.setter
    def Target(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Method(self) -> System.Reflection.MethodInfo: ...

    def get_Target(self) -> object: ...

    def op_Equality(self, _: Any, __: Any) -> bool: ...

    def op_Inequality(self, _: Any, __: Any) -> bool: ...


class XmlSchemaAnnotation:

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    @property
    def Items(self): ...

    @Items.setter
    def Items(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Id(self) -> str: ...

    def get_Items(self) -> XmlSchemaObjectCollection: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_SourceUri(self) -> str: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def set_Id(self, _: str) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...


class ValidationEventArgs:

    def Empty(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def Exception(self): ...

    @Exception.setter
    def Exception(self): ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Message(self): ...

    @Message.setter
    def Message(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def Severity(self): ...

    @Severity.setter
    def Severity(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Exception(self) -> XmlSchemaException: ...

    def get_Message(self) -> str: ...

    def get_Severity(self) -> XmlSeverityType: ...


class XmlSchemaSimpleTypeContent:

    @property
    def Annotation(self): ...

    @Annotation.setter
    def Annotation(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Annotation(self) -> XmlSchemaAnnotation: ...

    def get_Id(self) -> str: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_SourceUri(self) -> str: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def set_Annotation(self, _: XmlSchemaAnnotation) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...


class XmlSchemaContent:

    @property
    def Annotation(self): ...

    @Annotation.setter
    def Annotation(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Annotation(self) -> XmlSchemaAnnotation: ...

    def get_Id(self) -> str: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_SourceUri(self) -> str: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def set_Annotation(self, _: XmlSchemaAnnotation) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...


class XmlSchemaContentType:

    def CompareTo(self, _: object) -> int: ...

    def ElementOnly(self, *args, **kwargs) -> Any: ...

    def Empty(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Mixed(self, *args, **kwargs) -> Any: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def TextOnly(self, *args, **kwargs) -> Any: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class XmlSchemaException:

    @property
    def Data(self): ...

    @Data.setter
    def Data(self): ...

    def GetBaseException(self) -> Exception: ...

    def GetObjectData(self,
            _: System.Runtime.Serialization.SerializationInfo,
            __: System.Runtime.Serialization.StreamingContext,
            ) -> None: ...

    def GetType(self) -> Type: ...

    @property
    def HResult(self): ...

    @HResult.setter
    def HResult(self): ...

    @property
    def HelpLink(self): ...

    @HelpLink.setter
    def HelpLink(self): ...

    @property
    def InnerException(self): ...

    @InnerException.setter
    def InnerException(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    @property
    def Message(self): ...

    @Message.setter
    def Message(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def SerializeObjectState(self, *args, **kwargs) -> Any: ...

    @property
    def Source(self): ...

    @Source.setter
    def Source(self): ...

    @property
    def SourceSchemaObject(self): ...

    @SourceSchemaObject.setter
    def SourceSchemaObject(self): ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    @property
    def StackTrace(self): ...

    @StackTrace.setter
    def StackTrace(self): ...

    @property
    def TargetSite(self): ...

    @TargetSite.setter
    def TargetSite(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def add_SerializeObjectState(self, _: Any) -> None: ...

    def args(self, *args, **kwargs) -> Any: ...

    def get_Data(self) -> System.Collections.IDictionary: ...

    def get_HResult(self) -> int: ...

    def get_HelpLink(self) -> str: ...

    def get_InnerException(self) -> Exception: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Message(self) -> str: ...

    def get_Source(self) -> str: ...

    def get_SourceSchemaObject(self) -> XmlSchemaObject: ...

    def get_SourceUri(self) -> str: ...

    def get_StackTrace(self) -> str: ...

    def get_TargetSite(self) -> System.Reflection.MethodBase: ...

    def remove_SerializeObjectState(self, _: Any) -> None: ...

    def set_HResult(self, _: int) -> None: ...

    def set_HelpLink(self, _: str) -> None: ...

    def set_Source(self, _: str) -> None: ...

    def with_traceback(self, *args, **kwargs) -> Any: ...


class XmlSeverityType:

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Error(self, *args, **kwargs) -> Any: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def Warning(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class XmlSchemaContentProcessing:

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def Lax(self, *args, **kwargs) -> Any: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Skip(self, *args, **kwargs) -> Any: ...

    def Strict(self, *args, **kwargs) -> Any: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class XmlSchemaDatatypeVariety:

    def Atomic(self, *args, **kwargs) -> Any: ...

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def List(self, *args, **kwargs) -> Any: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def Union(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class IXmlSchemaInfo:

    @property
    def IsDefault(self): ...

    @IsDefault.setter
    def IsDefault(self): ...

    @property
    def IsNil(self): ...

    @IsNil.setter
    def IsNil(self): ...

    @property
    def MemberType(self): ...

    @MemberType.setter
    def MemberType(self): ...

    @property
    def SchemaAttribute(self): ...

    @SchemaAttribute.setter
    def SchemaAttribute(self): ...

    @property
    def SchemaElement(self): ...

    @SchemaElement.setter
    def SchemaElement(self): ...

    @property
    def SchemaType(self): ...

    @SchemaType.setter
    def SchemaType(self): ...

    @property
    def Validity(self): ...

    @Validity.setter
    def Validity(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_IsDefault(self) -> bool: ...

    def get_IsNil(self) -> bool: ...

    def get_MemberType(self) -> XmlSchemaSimpleType: ...

    def get_SchemaAttribute(self) -> XmlSchemaAttribute: ...

    def get_SchemaElement(self) -> XmlSchemaElement: ...

    def get_SchemaType(self) -> XmlSchemaType: ...

    def get_Validity(self) -> XmlSchemaValidity: ...


class XmlSchemaValidationFlags:

    def AllowXmlAttributes(self, *args, **kwargs) -> Any: ...

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ProcessIdentityConstraints(self, *args, **kwargs) -> Any: ...

    def ProcessInlineSchema(self, *args, **kwargs) -> Any: ...

    def ProcessSchemaLocation(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ReportValidationWarnings(self, *args, **kwargs) -> Any: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class XmlSchemaValidity:

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def Invalid(self, *args, **kwargs) -> Any: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def NotKnown(self, *args, **kwargs) -> Any: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def Valid(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class XmlSchemaElement:

    @property
    def Annotation(self): ...

    @Annotation.setter
    def Annotation(self): ...

    @property
    def Block(self): ...

    @Block.setter
    def Block(self): ...

    @property
    def BlockResolved(self): ...

    @BlockResolved.setter
    def BlockResolved(self): ...

    @property
    def Constraints(self): ...

    @Constraints.setter
    def Constraints(self): ...

    @property
    def DefaultValue(self): ...

    @DefaultValue.setter
    def DefaultValue(self): ...

    @property
    def ElementSchemaType(self): ...

    @ElementSchemaType.setter
    def ElementSchemaType(self): ...

    @property
    def ElementType(self): ...

    @ElementType.setter
    def ElementType(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def Final(self): ...

    @Final.setter
    def Final(self): ...

    @property
    def FinalResolved(self): ...

    @FinalResolved.setter
    def FinalResolved(self): ...

    def Finalize(self) -> None: ...

    @property
    def FixedValue(self): ...

    @FixedValue.setter
    def FixedValue(self): ...

    @property
    def Form(self): ...

    @Form.setter
    def Form(self): ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    @property
    def IsAbstract(self): ...

    @IsAbstract.setter
    def IsAbstract(self): ...

    @property
    def IsNillable(self): ...

    @IsNillable.setter
    def IsNillable(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    @property
    def MaxOccurs(self): ...

    @MaxOccurs.setter
    def MaxOccurs(self): ...

    @property
    def MaxOccursString(self): ...

    @MaxOccursString.setter
    def MaxOccursString(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def MinOccurs(self): ...

    @MinOccurs.setter
    def MinOccurs(self): ...

    @property
    def MinOccursString(self): ...

    @MinOccursString.setter
    def MinOccursString(self): ...

    @property
    def Name(self): ...

    @Name.setter
    def Name(self): ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    @property
    def QualifiedName(self): ...

    @QualifiedName.setter
    def QualifiedName(self): ...

    @property
    def RefName(self): ...

    @RefName.setter
    def RefName(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SchemaType(self): ...

    @SchemaType.setter
    def SchemaType(self): ...

    @property
    def SchemaTypeName(self): ...

    @SchemaTypeName.setter
    def SchemaTypeName(self): ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    @property
    def SubstitutionGroup(self): ...

    @SubstitutionGroup.setter
    def SubstitutionGroup(self): ...

    def ToString(self) -> str: ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Annotation(self) -> XmlSchemaAnnotation: ...

    def get_Block(self) -> XmlSchemaDerivationMethod: ...

    def get_BlockResolved(self) -> XmlSchemaDerivationMethod: ...

    def get_Constraints(self) -> XmlSchemaObjectCollection: ...

    def get_DefaultValue(self) -> str: ...

    def get_ElementSchemaType(self) -> XmlSchemaType: ...

    def get_ElementType(self) -> object: ...

    def get_Final(self) -> XmlSchemaDerivationMethod: ...

    def get_FinalResolved(self) -> XmlSchemaDerivationMethod: ...

    def get_FixedValue(self) -> str: ...

    def get_Form(self) -> XmlSchemaForm: ...

    def get_Id(self) -> str: ...

    def get_IsAbstract(self) -> bool: ...

    def get_IsNillable(self) -> bool: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_MaxOccurs(self) -> float: ...

    def get_MaxOccursString(self) -> str: ...

    def get_MinOccurs(self) -> float: ...

    def get_MinOccursString(self) -> str: ...

    def get_Name(self) -> str: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_QualifiedName(self) -> System.Xml.XmlQualifiedName: ...

    def get_RefName(self) -> System.Xml.XmlQualifiedName: ...

    def get_SchemaType(self) -> XmlSchemaType: ...

    def get_SchemaTypeName(self) -> System.Xml.XmlQualifiedName: ...

    def get_SourceUri(self) -> str: ...

    def get_SubstitutionGroup(self) -> System.Xml.XmlQualifiedName: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def set_Annotation(self, _: XmlSchemaAnnotation) -> None: ...

    def set_Block(self, _: XmlSchemaDerivationMethod) -> None: ...

    def set_DefaultValue(self, _: str) -> None: ...

    def set_Final(self, _: XmlSchemaDerivationMethod) -> None: ...

    def set_FixedValue(self, _: str) -> None: ...

    def set_Form(self, _: XmlSchemaForm) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_IsAbstract(self, _: bool) -> None: ...

    def set_IsNillable(self, _: bool) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_MaxOccurs(self, _: float) -> None: ...

    def set_MaxOccursString(self, _: str) -> None: ...

    def set_MinOccurs(self, _: float) -> None: ...

    def set_MinOccursString(self, _: str) -> None: ...

    def set_Name(self, _: str) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_RefName(self, _: System.Xml.XmlQualifiedName) -> None: ...

    def set_SchemaType(self, _: XmlSchemaType) -> None: ...

    def set_SchemaTypeName(self, _: System.Xml.XmlQualifiedName) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_SubstitutionGroup(self, _: System.Xml.XmlQualifiedName) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...


class XmlSchemaAttribute:

    @property
    def Annotation(self): ...

    @Annotation.setter
    def Annotation(self): ...

    @property
    def AttributeSchemaType(self): ...

    @AttributeSchemaType.setter
    def AttributeSchemaType(self): ...

    @property
    def AttributeType(self): ...

    @AttributeType.setter
    def AttributeType(self): ...

    @property
    def DefaultValue(self): ...

    @DefaultValue.setter
    def DefaultValue(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    @property
    def FixedValue(self): ...

    @FixedValue.setter
    def FixedValue(self): ...

    @property
    def Form(self): ...

    @Form.setter
    def Form(self): ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Name(self): ...

    @Name.setter
    def Name(self): ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    @property
    def QualifiedName(self): ...

    @QualifiedName.setter
    def QualifiedName(self): ...

    @property
    def RefName(self): ...

    @RefName.setter
    def RefName(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SchemaType(self): ...

    @SchemaType.setter
    def SchemaType(self): ...

    @property
    def SchemaTypeName(self): ...

    @SchemaTypeName.setter
    def SchemaTypeName(self): ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    @property
    def Use(self): ...

    @Use.setter
    def Use(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Annotation(self) -> XmlSchemaAnnotation: ...

    def get_AttributeSchemaType(self) -> XmlSchemaSimpleType: ...

    def get_AttributeType(self) -> object: ...

    def get_DefaultValue(self) -> str: ...

    def get_FixedValue(self) -> str: ...

    def get_Form(self) -> XmlSchemaForm: ...

    def get_Id(self) -> str: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Name(self) -> str: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_QualifiedName(self) -> System.Xml.XmlQualifiedName: ...

    def get_RefName(self) -> System.Xml.XmlQualifiedName: ...

    def get_SchemaType(self) -> XmlSchemaSimpleType: ...

    def get_SchemaTypeName(self) -> System.Xml.XmlQualifiedName: ...

    def get_SourceUri(self) -> str: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def get_Use(self) -> XmlSchemaUse: ...

    def set_Annotation(self, _: XmlSchemaAnnotation) -> None: ...

    def set_DefaultValue(self, _: str) -> None: ...

    def set_FixedValue(self, _: str) -> None: ...

    def set_Form(self, _: XmlSchemaForm) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Name(self, _: str) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_RefName(self, _: System.Xml.XmlQualifiedName) -> None: ...

    def set_SchemaType(self, _: XmlSchemaSimpleType) -> None: ...

    def set_SchemaTypeName(self, _: System.Xml.XmlQualifiedName) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...

    def set_Use(self, _: XmlSchemaUse) -> None: ...


class XmlSchemaUse:

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Optional(self, *args, **kwargs) -> Any: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def Prohibited(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Required(self, *args, **kwargs) -> Any: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...



from __future__ import annotations

from enum import Enum
from typing import Any, Dict, List, Type

import System
import System.Collections
import System.Configuration
import System.Configuration.Assemblies
import System.Data
import System.Globalization
import System.IO
import System.Reflection
import System.Runtime
import System.Runtime.CompilerServices
import System.Runtime.InteropServices
import System.Runtime.Remoting
import System.Runtime.Serialization
import System.Security
import System.Security.AccessControl
import System.Security.Cryptography
import System.Security.Cryptography.X509Certificates
import System.Security.Policy
import System.Threading
import System.Threading.Tasks
import System.Xml
import System.Xml.Schema
import System.Xml.Serialization
from System.ComponentModel import MarshalByValueComponent


class CancellationToken:

    @property
    def CanBeCanceled(self): ...

    @CanBeCanceled.setter
    def CanBeCanceled(self): ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def IsCancellationRequested(self): ...

    @IsCancellationRequested.setter
    def IsCancellationRequested(self): ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Register(self,
            _: System.Action[object],
            __: object,
            ___: bool,
            ) -> System.Threading.CancellationTokenRegistration: ...

    def ThrowIfCancellationRequested(self) -> None: ...

    def ToString(self) -> str: ...

    @property
    def WaitHandle(self): ...

    @WaitHandle.setter
    def WaitHandle(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_CanBeCanceled(self) -> bool: ...

    def get_IsCancellationRequested(self) -> bool: ...

    def get_None(self) -> System.Threading.CancellationToken: ...

    def get_WaitHandle(self) -> System.Threading.WaitHandle: ...

    def op_Equality(self,
            _: System.Threading.CancellationToken,
            __: System.Threading.CancellationToken,
            ) -> bool: ...

    def op_Inequality(self,
            _: System.Threading.CancellationToken,
            __: System.Threading.CancellationToken,
            ) -> bool: ...


class WaitHandle:

    def Close(self) -> None: ...

    def CreateObjRef(self, _: Type) -> System.Runtime.Remoting.ObjRef: ...

    def Dispose(self, _: bool) -> None: ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetLifetimeService(self) -> object: ...

    def GetType(self) -> Type: ...

    @property
    def Handle(self): ...

    @Handle.setter
    def Handle(self): ...

    def InitializeLifetimeService(self) -> object: ...

    def InvalidHandle(self, *args, **kwargs) -> Any: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SafeWaitHandle(self): ...

    @SafeWaitHandle.setter
    def SafeWaitHandle(self): ...

    def SignalAndWait(self,
            _: System.Threading.WaitHandle,
            __: System.Threading.WaitHandle,
            ___: int,
            ____: bool,
            ) -> bool: ...

    def ToString(self) -> str: ...

    def WaitAll(self,
            _: List[System.Threading.WaitHandle],
            __: int,
            ___: bool,
            ) -> bool: ...

    def WaitAny(self, _: List[System.Threading.WaitHandle], __: int, ___: bool) -> int: ...

    def WaitOne(self, _: int, __: bool) -> bool: ...

    def WaitTimeout(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Handle(self) -> Any: ...

    def get_SafeWaitHandle(self) -> Any: ...

    def set_Handle(self, _: Any) -> None: ...

    def set_SafeWaitHandle(self, _: Any) -> None: ...


class CancellationTokenRegistration:

    def Dispose(self) -> None: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def op_Equality(self,
            _: System.Threading.CancellationTokenRegistration,
            __: System.Threading.CancellationTokenRegistration,
            ) -> bool: ...

    def op_Inequality(self,
            _: System.Threading.CancellationTokenRegistration,
            __: System.Threading.CancellationTokenRegistration,
            ) -> bool: ...



from __future__ import annotations

from enum import Enum
from typing import Any, Dict, List, Type

import System
import System.Collections
import System.Configuration
import System.Configuration.Assemblies
import System.Data
import System.Globalization
import System.IO
import System.Reflection
import System.Runtime
import System.Runtime.CompilerServices
import System.Runtime.InteropServices
import System.Runtime.Remoting
import System.Runtime.Serialization
import System.Security
import System.Security.AccessControl
import System.Security.Cryptography
import System.Security.Cryptography.X509Certificates
import System.Security.Policy
import System.Threading
import System.Threading.Tasks
import System.Xml
import System.Xml.Schema
import System.Xml.Serialization
from System.ComponentModel import MarshalByValueComponent


class FileSecurity:

    @property
    def AccessRightType(self): ...

    @AccessRightType.setter
    def AccessRightType(self): ...

    def AccessRuleFactory(self,
            _: System.Security.Principal.IdentityReference,
            __: int,
            ___: bool,
            ____: System.Security.AccessControl.InheritanceFlags,
            _____: System.Security.AccessControl.PropagationFlags,
            ______: System.Security.AccessControl.AccessControlType,
            ) -> System.Security.AccessControl.AccessRule: ...

    @property
    def AccessRuleType(self): ...

    @AccessRuleType.setter
    def AccessRuleType(self): ...

    @property
    def AccessRulesModified(self): ...

    @AccessRulesModified.setter
    def AccessRulesModified(self): ...

    def AddAccessRule(self, _: System.Security.AccessControl.AccessRule) -> None: ...

    def AddAuditRule(self, _: System.Security.AccessControl.AuditRule) -> None: ...

    @property
    def AreAccessRulesCanonical(self): ...

    @AreAccessRulesCanonical.setter
    def AreAccessRulesCanonical(self): ...

    @property
    def AreAccessRulesProtected(self): ...

    @AreAccessRulesProtected.setter
    def AreAccessRulesProtected(self): ...

    @property
    def AreAuditRulesCanonical(self): ...

    @AreAuditRulesCanonical.setter
    def AreAuditRulesCanonical(self): ...

    @property
    def AreAuditRulesProtected(self): ...

    @AreAuditRulesProtected.setter
    def AreAuditRulesProtected(self): ...

    def AuditRuleFactory(self,
            _: System.Security.Principal.IdentityReference,
            __: int,
            ___: bool,
            ____: System.Security.AccessControl.InheritanceFlags,
            _____: System.Security.AccessControl.PropagationFlags,
            ______: System.Security.AccessControl.AuditFlags,
            ) -> System.Security.AccessControl.AuditRule: ...

    @property
    def AuditRuleType(self): ...

    @AuditRuleType.setter
    def AuditRuleType(self): ...

    @property
    def AuditRulesModified(self): ...

    @AuditRulesModified.setter
    def AuditRulesModified(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def ExceptionFromErrorCode(self, *args, **kwargs) -> Any: ...

    def Finalize(self) -> None: ...

    def GetAccessRules(self,
            _: bool,
            __: bool,
            ___: Type,
            ) -> System.Security.AccessControl.AuthorizationRuleCollection: ...

    def GetAuditRules(self,
            _: bool,
            __: bool,
            ___: Type,
            ) -> System.Security.AccessControl.AuthorizationRuleCollection: ...

    def GetGroup(self, _: Type) -> System.Security.Principal.IdentityReference: ...

    def GetHashCode(self) -> int: ...

    def GetOwner(self, _: Type) -> System.Security.Principal.IdentityReference: ...

    def GetSecurityDescriptorBinaryForm(self) -> List[bytes]: ...

    def GetSecurityDescriptorSddlForm(self,
            _: System.Security.AccessControl.AccessControlSections,
            ) -> str: ...

    def GetType(self) -> Type: ...

    @property
    def GroupModified(self): ...

    @GroupModified.setter
    def GroupModified(self): ...

    @property
    def IsContainer(self): ...

    @IsContainer.setter
    def IsContainer(self): ...

    @property
    def IsDS(self): ...

    @IsDS.setter
    def IsDS(self): ...

    def IsSddlConversionSupported(self) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def ModifyAccess(self,
            _: System.Security.AccessControl.AccessControlModification,
            __: System.Security.AccessControl.AccessRule,
            ___: bool,
            ) -> bool: ...

    def ModifyAccessRule(self,
            _: System.Security.AccessControl.AccessControlModification,
            __: System.Security.AccessControl.AccessRule,
            ___: bool,
            ) -> bool: ...

    def ModifyAudit(self,
            _: System.Security.AccessControl.AccessControlModification,
            __: System.Security.AccessControl.AuditRule,
            ___: bool,
            ) -> bool: ...

    def ModifyAuditRule(self,
            _: System.Security.AccessControl.AccessControlModification,
            __: System.Security.AccessControl.AuditRule,
            ___: bool,
            ) -> bool: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def OwnerModified(self): ...

    @OwnerModified.setter
    def OwnerModified(self): ...

    def Persist(self,
            _: bool,
            __: str,
            ___: System.Security.AccessControl.AccessControlSections,
            ) -> None: ...

    def PurgeAccessRules(self, _: System.Security.Principal.IdentityReference) -> None: ...

    def PurgeAuditRules(self, _: System.Security.Principal.IdentityReference) -> None: ...

    def ReadLock(self) -> None: ...

    def ReadUnlock(self) -> None: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def RemoveAccessRule(self, _: System.Security.AccessControl.AccessRule) -> bool: ...

    def RemoveAccessRuleAll(self, _: System.Security.AccessControl.AccessRule) -> None: ...

    def RemoveAccessRuleSpecific(self,
            _: System.Security.AccessControl.AccessRule,
            ) -> None: ...

    def RemoveAuditRule(self, _: System.Security.AccessControl.AuditRule) -> bool: ...

    def RemoveAuditRuleAll(self, _: System.Security.AccessControl.AuditRule) -> None: ...

    def RemoveAuditRuleSpecific(self,
            _: System.Security.AccessControl.AuditRule,
            ) -> None: ...

    def ResetAccessRule(self, _: System.Security.AccessControl.AccessRule) -> None: ...

    def SetAccessRule(self, _: System.Security.AccessControl.AccessRule) -> None: ...

    def SetAccessRuleProtection(self, _: bool, __: bool) -> None: ...

    def SetAuditRule(self, _: System.Security.AccessControl.AuditRule) -> None: ...

    def SetAuditRuleProtection(self, _: bool, __: bool) -> None: ...

    def SetGroup(self, _: System.Security.Principal.IdentityReference) -> None: ...

    def SetOwner(self, _: System.Security.Principal.IdentityReference) -> None: ...

    def SetSecurityDescriptorBinaryForm(self,
            _: List[bytes],
            __: System.Security.AccessControl.AccessControlSections,
            ) -> None: ...

    def SetSecurityDescriptorSddlForm(self,
            _: str,
            __: System.Security.AccessControl.AccessControlSections,
            ) -> None: ...

    def ToString(self) -> str: ...

    def WriteLock(self) -> None: ...

    def WriteUnlock(self) -> None: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_AccessRightType(self) -> Type: ...

    def get_AccessRuleType(self) -> Type: ...

    def get_AccessRulesModified(self) -> bool: ...

    def get_AreAccessRulesCanonical(self) -> bool: ...

    def get_AreAccessRulesProtected(self) -> bool: ...

    def get_AreAuditRulesCanonical(self) -> bool: ...

    def get_AreAuditRulesProtected(self) -> bool: ...

    def get_AuditRuleType(self) -> Type: ...

    def get_AuditRulesModified(self) -> bool: ...

    def get_GroupModified(self) -> bool: ...

    def get_IsContainer(self) -> bool: ...

    def get_IsDS(self) -> bool: ...

    def get_OwnerModified(self) -> bool: ...

    def set_AccessRulesModified(self, _: bool) -> None: ...

    def set_AuditRulesModified(self, _: bool) -> None: ...

    def set_GroupModified(self, _: bool) -> None: ...

    def set_OwnerModified(self, _: bool) -> None: ...



from __future__ import annotations

from enum import Enum
from typing import Any, Dict, List, Type

import System
import System.Configuration
import System.Configuration.Assemblies
import System.Data
import System.Globalization
import System.IO
import System.Reflection
import System.Runtime
import System.Runtime.CompilerServices
import System.Runtime.InteropServices
import System.Runtime.Remoting
import System.Runtime.Serialization
import System.Security
import System.Security.AccessControl
import System.Security.Cryptography
import System.Security.Cryptography.X509Certificates
import System.Security.Policy
import System.Threading
import System.Threading.Tasks
import System.Xml
import System.Xml.Schema
import System.Xml.Serialization
from System.ComponentModel import MarshalByValueComponent


class IEnumerator:

    @property
    def Current(self): ...

    @Current.setter
    def Current(self): ...

    def MoveNext(self) -> bool: ...

    def Reset(self) -> None: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Current(self) -> object: ...


class IDictionary:

    def Add(self, _: object, __: object) -> None: ...

    def Clear(self) -> None: ...

    def Contains(self, _: object) -> bool: ...

    def CopyTo(self, _: List, __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def GetEnumerator(self) -> IDictionaryEnumerator: ...

    @property
    def IsFixedSize(self): ...

    @IsFixedSize.setter
    def IsFixedSize(self): ...

    @property
    def IsReadOnly(self): ...

    @IsReadOnly.setter
    def IsReadOnly(self): ...

    @property
    def IsSynchronized(self): ...

    @IsSynchronized.setter
    def IsSynchronized(self): ...

    @property
    def Keys(self): ...

    @Keys.setter
    def Keys(self): ...

    def Remove(self, _: object) -> None: ...

    @property
    def SyncRoot(self): ...

    @SyncRoot.setter
    def SyncRoot(self): ...

    @property
    def Values(self): ...

    @Values.setter
    def Values(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Count(self) -> int: ...

    def get_IsFixedSize(self) -> bool: ...

    def get_IsReadOnly(self) -> bool: ...

    def get_IsSynchronized(self) -> bool: ...

    def get_Item(self, _: object) -> object: ...

    def get_Keys(self) -> ICollection: ...

    def get_SyncRoot(self) -> object: ...

    def get_Values(self) -> ICollection: ...

    def set_Item(self, _: object, __: object) -> None: ...


class ArrayList:

    def Adapter(self, _: List) -> List: ...

    def Add(self, _: object) -> int: ...

    def AddRange(self, _: ICollection) -> None: ...

    def BinarySearch(self,
            _: int,
            __: int,
            ___: object,
            ____: IComparer,
            ) -> int: ...

    @property
    def Capacity(self): ...

    @Capacity.setter
    def Capacity(self): ...

    def Clear(self) -> None: ...

    def Clone(self) -> object: ...

    def Contains(self, _: object) -> bool: ...

    def CopyTo(self, _: int, __: List, ___: int, ____: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def FixedSize(self, _: List) -> List: ...

    def GetEnumerator(self, _: int, __: int) -> IEnumerator: ...

    def GetHashCode(self) -> int: ...

    def GetRange(self, _: int, __: int) -> List: ...

    def GetType(self) -> Type: ...

    def IndexOf(self, _: object, __: int, ___: int) -> int: ...

    def Insert(self, _: int, __: object) -> None: ...

    def InsertRange(self, _: int, __: ICollection) -> None: ...

    @property
    def IsFixedSize(self): ...

    @IsFixedSize.setter
    def IsFixedSize(self): ...

    @property
    def IsReadOnly(self): ...

    @IsReadOnly.setter
    def IsReadOnly(self): ...

    @property
    def IsSynchronized(self): ...

    @IsSynchronized.setter
    def IsSynchronized(self): ...

    def LastIndexOf(self, _: object, __: int, ___: int) -> int: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReadOnly(self, _: List) -> List: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: object) -> None: ...

    def RemoveAt(self, _: int) -> None: ...

    def RemoveRange(self, _: int, __: int) -> None: ...

    def Repeat(self, _: object, __: int) -> List: ...

    def Reverse(self, _: int, __: int) -> None: ...

    def SetRange(self, _: int, __: ICollection) -> None: ...

    def Sort(self, _: int, __: int, ___: IComparer) -> None: ...

    @property
    def SyncRoot(self): ...

    @SyncRoot.setter
    def SyncRoot(self): ...

    def Synchronized(self, _: List) -> List: ...

    def ToArray(self, _: Type) -> List: ...

    def ToString(self) -> str: ...

    def TrimToSize(self) -> None: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Capacity(self) -> int: ...

    def get_Count(self) -> int: ...

    def get_IsFixedSize(self) -> bool: ...

    def get_IsReadOnly(self) -> bool: ...

    def get_IsSynchronized(self) -> bool: ...

    def get_Item(self, _: int) -> object: ...

    def get_SyncRoot(self) -> object: ...

    def set_Capacity(self, _: int) -> None: ...

    def set_Item(self, _: int, __: object) -> None: ...


class IDictionaryEnumerator:

    @property
    def Current(self): ...

    @Current.setter
    def Current(self): ...

    @property
    def Entry(self): ...

    @Entry.setter
    def Entry(self): ...

    @property
    def Key(self): ...

    @Key.setter
    def Key(self): ...

    def MoveNext(self) -> bool: ...

    def Reset(self) -> None: ...

    @property
    def Value(self): ...

    @Value.setter
    def Value(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Current(self) -> object: ...

    def get_Entry(self) -> DictionaryEntry: ...

    def get_Key(self) -> object: ...

    def get_Value(self) -> object: ...


class IEqualityComparer:

    def Equals(self, _: object, __: object) -> bool: ...

    def GetHashCode(self, _: object) -> int: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class ICollection:

    def CopyTo(self, _: List, __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def GetEnumerator(self) -> IEnumerator: ...

    @property
    def IsSynchronized(self): ...

    @IsSynchronized.setter
    def IsSynchronized(self): ...

    @property
    def SyncRoot(self): ...

    @SyncRoot.setter
    def SyncRoot(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Count(self) -> int: ...

    def get_IsSynchronized(self) -> bool: ...

    def get_SyncRoot(self) -> object: ...


class IHashCodeProvider:

    def GetHashCode(self, _: object) -> int: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class IComparer:

    def Compare(self, _: object, __: object) -> int: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class Hashtable:

    def Add(self, _: object, __: object) -> None: ...

    def Clear(self) -> None: ...

    def Clone(self) -> object: ...

    def Contains(self, _: object) -> bool: ...

    def ContainsKey(self, _: object) -> bool: ...

    def ContainsValue(self, _: object) -> bool: ...

    def CopyTo(self, _: List, __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    @property
    def EqualityComparer(self): ...

    @EqualityComparer.setter
    def EqualityComparer(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetEnumerator(self) -> IDictionaryEnumerator: ...

    def GetHash(self, _: object) -> int: ...

    def GetHashCode(self) -> int: ...

    def GetObjectData(self,
            _: System.Runtime.Serialization.SerializationInfo,
            __: System.Runtime.Serialization.StreamingContext,
            ) -> None: ...

    def GetType(self) -> Type: ...

    @property
    def IsFixedSize(self): ...

    @IsFixedSize.setter
    def IsFixedSize(self): ...

    @property
    def IsReadOnly(self): ...

    @IsReadOnly.setter
    def IsReadOnly(self): ...

    @property
    def IsSynchronized(self): ...

    @IsSynchronized.setter
    def IsSynchronized(self): ...

    def KeyEquals(self, _: object, __: object) -> bool: ...

    @property
    def Keys(self): ...

    @Keys.setter
    def Keys(self): ...

    def MemberwiseClone(self) -> object: ...

    def OnDeserialization(self, _: object) -> None: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: object) -> None: ...

    @property
    def SyncRoot(self): ...

    @SyncRoot.setter
    def SyncRoot(self): ...

    def Synchronized(self,
            _: Hashtable,
            ) -> Hashtable: ...

    def ToString(self) -> str: ...

    @property
    def Values(self): ...

    @Values.setter
    def Values(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    @property
    def comparer(self): ...

    @comparer.setter
    def comparer(self): ...

    def get_Count(self) -> int: ...

    def get_EqualityComparer(self) -> IEqualityComparer: ...

    def get_IsFixedSize(self) -> bool: ...

    def get_IsReadOnly(self) -> bool: ...

    def get_IsSynchronized(self) -> bool: ...

    def get_Item(self, _: object) -> object: ...

    def get_Keys(self) -> ICollection: ...

    def get_SyncRoot(self) -> object: ...

    def get_Values(self) -> ICollection: ...

    def get_comparer(self) -> IComparer: ...

    def get_hcp(self) -> IHashCodeProvider: ...

    @property
    def hcp(self): ...

    @hcp.setter
    def hcp(self): ...

    def set_Item(self, _: object, __: object) -> None: ...

    def set_comparer(self, _: IComparer) -> None: ...

    def set_hcp(self, _: IHashCodeProvider) -> None: ...


class DictionaryEntry:

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Key(self): ...

    @Key.setter
    def Key(self): ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToString(self) -> str: ...

    @property
    def Value(self): ...

    @Value.setter
    def Value(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Key(self) -> object: ...

    def get_Value(self) -> object: ...

    def set_Key(self, _: object) -> None: ...

    def set_Value(self, _: object) -> None: ...


class IList:

    def Add(self, _: object) -> int: ...

    def Clear(self) -> None: ...

    def Contains(self, _: object) -> bool: ...

    def CopyTo(self, _: List, __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def GetEnumerator(self) -> IEnumerator: ...

    def IndexOf(self, _: object) -> int: ...

    def Insert(self, _: int, __: object) -> None: ...

    @property
    def IsFixedSize(self): ...

    @IsFixedSize.setter
    def IsFixedSize(self): ...

    @property
    def IsReadOnly(self): ...

    @IsReadOnly.setter
    def IsReadOnly(self): ...

    @property
    def IsSynchronized(self): ...

    @IsSynchronized.setter
    def IsSynchronized(self): ...

    def Remove(self, _: object) -> None: ...

    def RemoveAt(self, _: int) -> None: ...

    @property
    def SyncRoot(self): ...

    @SyncRoot.setter
    def SyncRoot(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Count(self) -> int: ...

    def get_IsFixedSize(self) -> bool: ...

    def get_IsReadOnly(self) -> bool: ...

    def get_IsSynchronized(self) -> bool: ...

    def get_Item(self, _: int) -> object: ...

    def get_SyncRoot(self) -> object: ...

    def set_Item(self, _: int, __: object) -> None: ...



from __future__ import annotations

from enum import Enum
from typing import Any, Dict, List, Type

import System
import System.Collections
import System.Configuration
import System.Configuration.Assemblies
import System.Data
import System.Globalization
import System.IO
import System.Reflection
import System.Runtime
import System.Runtime.CompilerServices
import System.Runtime.Remoting
import System.Runtime.Serialization
import System.Security
import System.Security.AccessControl
import System.Security.Cryptography
import System.Security.Cryptography.X509Certificates
import System.Security.Policy
import System.Threading
import System.Threading.Tasks
import System.Xml
import System.Xml.Schema
import System.Xml.Serialization
from System.ComponentModel import MarshalByValueComponent


class StructLayoutAttribute:

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetCustomAttribute(self,
            _: System.Reflection.ParameterInfo,
            __: Type,
            ___: bool,
            ) -> System.Attribute: ...

    def GetCustomAttributes(self,
            _: System.Reflection.ParameterInfo,
            __: Type,
            ___: bool,
            ) -> List[System.Attribute]: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def IsDefaultAttribute(self) -> bool: ...

    def IsDefined(self,
            _: System.Reflection.ParameterInfo,
            __: Type,
            ___: bool,
            ) -> bool: ...

    def Match(self, _: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToString(self) -> str: ...

    @property
    def TypeId(self): ...

    @TypeId.setter
    def TypeId(self): ...

    @property
    def Value(self): ...

    @Value.setter
    def Value(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_TypeId(self) -> object: ...

    def get_Value(self) -> LayoutKind: ...



from __future__ import annotations

from enum import Enum
from typing import Any, Dict, List, Type

import System
import System.Collections
import System.Configuration
import System.Configuration.Assemblies
import System.Data
import System.Globalization
import System.IO
import System.Reflection
import System.Runtime
import System.Runtime.CompilerServices
import System.Runtime.InteropServices
import System.Runtime.Remoting
import System.Security
import System.Security.AccessControl
import System.Security.Cryptography
import System.Security.Cryptography.X509Certificates
import System.Security.Policy
import System.Threading
import System.Threading.Tasks
import System.Xml
import System.Xml.Schema
import System.Xml.Serialization
from System.ComponentModel import MarshalByValueComponent


class StreamingContextStates:

    def All(self, *args, **kwargs) -> Any: ...

    def Clone(self, *args, **kwargs) -> Any: ...

    def CompareTo(self, _: object) -> int: ...

    def CrossAppDomain(self, *args, **kwargs) -> Any: ...

    def CrossMachine(self, *args, **kwargs) -> Any: ...

    def CrossProcess(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object) -> bool: ...

    def File(self, *args, **kwargs) -> Any: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Other(self, *args, **kwargs) -> Any: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def Persistence(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remoting(self, *args, **kwargs) -> Any: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class SerializationEntry:

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Name(self): ...

    @Name.setter
    def Name(self): ...

    @property
    def ObjectType(self): ...

    @ObjectType.setter
    def ObjectType(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToString(self) -> str: ...

    @property
    def Value(self): ...

    @Value.setter
    def Value(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Name(self) -> str: ...

    def get_ObjectType(self) -> Type: ...

    def get_Value(self) -> object: ...


class SerializationInfo:

    def AddValue(self, _: str, __: object, ___: Type) -> None: ...

    @property
    def AssemblyName(self): ...

    @AssemblyName.setter
    def AssemblyName(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    @property
    def FullTypeName(self): ...

    @FullTypeName.setter
    def FullTypeName(self): ...

    def GetBoolean(self, _: str) -> bool: ...

    def GetByte(self, _: str) -> bytes: ...

    def GetChar(self, _: str) -> str: ...

    def GetDateTime(self, _: str) -> System.DateTime: ...

    def GetDecimal(self, _: str) -> float: ...

    def GetDouble(self, _: str) -> float: ...

    def GetEnumerator(self) -> SerializationInfoEnumerator: ...

    def GetHashCode(self) -> int: ...

    def GetInt16(self, _: str) -> int: ...

    def GetInt32(self, _: str) -> int: ...

    def GetInt64(self, _: str) -> int: ...

    def GetSByte(self, _: str) -> bytes: ...

    def GetSingle(self, _: str) -> float: ...

    def GetString(self, _: str) -> str: ...

    def GetType(self) -> Type: ...

    def GetUInt16(self, _: str) -> int: ...

    def GetUInt32(self, _: str) -> int: ...

    def GetUInt64(self, _: str) -> int: ...

    def GetValue(self, _: str, __: Type) -> object: ...

    @property
    def IsAssemblyNameSetExplicit(self): ...

    @IsAssemblyNameSetExplicit.setter
    def IsAssemblyNameSetExplicit(self): ...

    @property
    def IsFullTypeNameSetExplicit(self): ...

    @IsFullTypeNameSetExplicit.setter
    def IsFullTypeNameSetExplicit(self): ...

    @property
    def MemberCount(self): ...

    @MemberCount.setter
    def MemberCount(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def ObjectType(self): ...

    @ObjectType.setter
    def ObjectType(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def SetType(self, _: Type) -> None: ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_AssemblyName(self) -> str: ...

    def get_FullTypeName(self) -> str: ...

    def get_IsAssemblyNameSetExplicit(self) -> bool: ...

    def get_IsFullTypeNameSetExplicit(self) -> bool: ...

    def get_MemberCount(self) -> int: ...

    def get_ObjectType(self) -> Type: ...

    def set_AssemblyName(self, _: str) -> None: ...

    def set_FullTypeName(self, _: str) -> None: ...


class StreamingContext:

    @property
    def Context(self): ...

    @Context.setter
    def Context(self): ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def State(self): ...

    @State.setter
    def State(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Context(self) -> object: ...

    def get_State(self) -> StreamingContextStates: ...


class SerializationInfoEnumerator:

    @property
    def Current(self): ...

    @Current.setter
    def Current(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    def MoveNext(self) -> bool: ...

    @property
    def Name(self): ...

    @Name.setter
    def Name(self): ...

    @property
    def ObjectType(self): ...

    @ObjectType.setter
    def ObjectType(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Reset(self) -> None: ...

    def ToString(self) -> str: ...

    @property
    def Value(self): ...

    @Value.setter
    def Value(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Current(self) -> SerializationEntry: ...

    def get_Name(self) -> str: ...

    def get_ObjectType(self) -> Type: ...

    def get_Value(self) -> object: ...


class SafeSerializationEventArgs:

    def AddSerializedState(self,
            _: ISafeSerializationData,
            ) -> None: ...

    def Empty(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def StreamingContext(self): ...

    @StreamingContext.setter
    def StreamingContext(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_StreamingContext(self) -> StreamingContext: ...



from __future__ import annotations

from enum import Enum
from typing import Any, Dict, List, Type

import System
import System.Collections
import System.Configuration
import System.Configuration.Assemblies
import System.Data
import System.Globalization
import System.IO
import System.Reflection
import System.Runtime
import System.Runtime.CompilerServices
import System.Runtime.InteropServices
import System.Runtime.Remoting
import System.Runtime.Serialization
import System.Security
import System.Security.AccessControl
import System.Security.Cryptography
import System.Security.Cryptography.X509Certificates
import System.Security.Policy
import System.Threading
import System.Threading.Tasks
import System.Xml
import System.Xml.Schema
from System.ComponentModel import MarshalByValueComponent


class XmlSerializerNamespaces:

    def Add(self, _: str, __: str) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToArray(self) -> List[System.Xml.XmlQualifiedName]: ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Count(self) -> int: ...
